pm4py.evaluation.earth\_mover\_distance.variants package
========================================================

Submodules
----------

pm4py.evaluation.earth\_mover\_distance.variants.pyemd module
-------------------------------------------------------------

.. automodule:: pm4py.evaluation.earth_mover_distance.variants.pyemd
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.earth_mover_distance.variants
   :members:
   :undoc-members:
   :show-inheritance:
